Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(868)

Unified Diff: runtime/vm/intrinsifier_arm64.cc

Issue 2005723004: Fraction class prototype and test (not to be committed). (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: work in progress Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/intrinsifier_arm.cc ('k') | runtime/vm/intrinsifier_ia32.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/intrinsifier_arm64.cc
diff --git a/runtime/vm/intrinsifier_arm64.cc b/runtime/vm/intrinsifier_arm64.cc
index f9cade23e23862b21a0e420bfca5e49edc80bee3..e7466ad1e673172f644c1ba4ec2184fbd0dd9f3f 100644
--- a/runtime/vm/intrinsifier_arm64.cc
+++ b/runtime/vm/intrinsifier_arm64.cc
@@ -608,11 +608,14 @@ void Intrinsifier::Integer_equalToInteger(Assembler* assembler) {
__ tsti(R1, Immediate(kSmiTagMask)); // Check receiver.
__ b(&receiver_not_smi, NE);
// Left (receiver) is Smi, return false if right is not Double.
// Note that an instance of Mint or Bigint never contains a value that can be
// represented by Smi.
- __ CompareClassId(R0, kDoubleCid);
+ __ LoadClassId(TMP, R0);
+ __ CompareImmediate(TMP, kDoubleCid);
+ __ b(&fall_through, EQ);
+ __ CompareImmediate(TMP, kFractionCid);
__ b(&fall_through, EQ);
__ LoadObject(R0, Bool::False()); // Smi == Mint -> false.
__ ret();
@@ -608,11 +608,14 @@ void Intrinsifier::Integer_equalToInteger(Assembler* assembler) {
__ tsti(R1, Immediate(kSmiTagMask)); // Check receiver.
__ b(&receiver_not_smi, NE);
- // Left (receiver) is Smi, return false if right is not Double.
+ // Left (receiver) is Smi, return false if right is not Double or Fraction.
// Note that an instance of Mint or Bigint never contains a value that can be
// represented by Smi.
« no previous file with comments | « runtime/vm/intrinsifier_arm.cc ('k') | runtime/vm/intrinsifier_ia32.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698